package mvd.jester.info;

import java.util.HashSet;
import java.util.Optional;
import java.util.Set;

/**
 * DeadlineMissInfo
 */
public class SchedulingInfo {

    private final Set<TerminationInfo> terminationInfos;
    private Optional<TerminationInfo> failedTerminationInfo;

    public SchedulingInfo() {
        this.terminationInfos = new HashSet<>();
        this.failedTerminationInfo = Optional.empty();
    }

    public SchedulingInfo(Set<TerminationInfo> terminationInfos) {
        this.terminationInfos = terminationInfos;
        failedTerminationInfo =
                terminationInfos.stream().filter(t -> t.getLateness() > 0).findFirst();
    }

    public boolean checkTasksetFeasible() {
        // return terminationInfos.isEmpty();
        return !terminationInfos.stream().anyMatch(t -> t.getLateness() > 0);
    }

    public void addTerminationInfo(TerminationInfo terminationInfo) {
        terminationInfos.add(terminationInfo);
    }

    /**
     * @return the terminationInfos
     */
    public Set<TerminationInfo> getTerminationInfos() {
        return terminationInfos;
    }

    /**
     * @return the failedTerminationInfo
     */
    public Optional<TerminationInfo> getFailedTerminationInfo() {
        return failedTerminationInfo;
    }

    public void setFailedTemrinationInfo(TerminationInfo failedTerminationInfo) {
        this.failedTerminationInfo = Optional.of(failedTerminationInfo);
    }
}
